module Documentum
  class Generator

    attr_reader :template_filename, :stylesheet_filenames, :output_dir, :options

    def initialize(template_filename, output_dir, stylesheet_filenames: [], options: {})
      @template_filename = template_filename
      @stylesheet_filenames = stylesheet_filenames
      @output_dir = output_dir
    end

    def generate_pdf(markdown_filename)
      html = generate_html(markdown_filename)
      engine = PDFKit.new(html, page_size: "Letter")
      engine.stylesheets += @stylesheet_filenames
      engine.to_file(output_path(markdown_filename))
    end

    private

    def output_path(markdown_filename)
      path = Pathname.new(markdown_filename)
      filename = path.basename.to_s.sub(path.extname, ".pdf")
      "#{@output_dir}/#{filename}"
    end

    def template
      @template ||= File.read(@template_filename)
    end

    def generate_html(markdown_filename)
      markdown = File.read(markdown_filename)
      engine = Haml::Engine.new(template)
      engine.render(Object.new, { content: markdown })
    end

  end
end
